<template>
  <Popup ref="pop" :title="title" left="calc(100% - 330px)">
    <div class="sunshineAnalysis">
      <el-form ref="form" :model="form" :rules="rules" label-width="105px">
        <el-form-item prop="date" label="日期选择">
          <el-date-picker
            v-model="form.date"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="选择日期"
          >
          </el-date-picker>
        </el-form-item>
        <el-form-item prop="startTime" label="开始时间">
          <el-time-select
            v-model="form.startTime"
            :picker-options="{
              start: '00:00',
              step: '00:15',
              end: '23:45',
            }"
            placeholder="开始时间"
          >
          </el-time-select>
        </el-form-item>
        <el-form-item prop="endTime" label="结束时间">
          <el-time-select
            :picker-options="{
              start: '00:00',
              step: '00:15',
              end: '23:45',
            }"
            v-model="form.endTime"
            placeholder="结束时间"
          >
          </el-time-select>
        </el-form-item>
        <el-form-item prop="timeInterval" label="时间间隔">
          <el-input v-model.number="form.timeInterval"></el-input>
        </el-form-item>
        <el-form-item prop="spaceInterval" label="空间间隔">
          <el-input v-model.number="form.spaceInterval"></el-input>
        </el-form-item>
        <el-form-item prop="dropHeight" label="拉伸高度">
          <el-input v-model.number="form.dropHeight"></el-input>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" @click="submitForm('form')">
            开始分析
          </el-button>
        </el-form-item>
      </el-form>
    </div>
  </Popup>
</template>

<script>
import Popup from "@tools/Popup.vue";
export default {
  name: "sunshineAnalysis",
  components: {
    Popup,
  },
  data() {
    var checkEndTime = (rule, value, callback) => {
      if (value < this.form.startTime) {
        callback(new Error("结束时间小于开始时间"));
      } else {
        callback();
      }
    };
    var checkNumber = (rule, value, callback) => {
      if (!Number.isInteger(value)) {
        callback(new Error("请输入数字值"));
      } else {
        callback();
      }
    };
    return {
      title: "日照分析",
      form: {
        date: "2021-12-01",
        startTime: "06:00",
        endTime: "10:00",
        timeInterval: 60,
        spaceInterval: 10,
        dropHeight: 30,
      },
      rules: {
        date: [{ required: true, message: "请选择日期", trigger: "change" }],
        startTime: [
          { required: true, message: "请选择开始时间", trigger: "change" },
        ],
        endTime: [
          {
            required: true,
            validator: checkEndTime,
            trigger: "blur",
          },
        ],
        timeInterval: [
          { required: true, validator: checkNumber, trigger: "blur" },
        ],
        spaceInterval: [
          { required: true, validator: checkNumber, trigger: "blur" },
        ],
        dropHeight: [
          { required: true, validator: checkNumber, trigger: "blur" },
        ],
      },
    };
  },
  methods: {
    open() {
      this.$refs.pop.open();
    },
    close() {
      this.$refs.pop.close();
    },
    submitForm(formName) {
      this.$refs[formName].validate((valid) => {
        if (valid) {
          var startTime = this.form.date + " " + this.form.startTime;
          var endTime = this.form.date + " " + this.form.endTime;
          window._AnalysisSunshine =
            window.sgworld.Analysis.SunshineAnalysisPolygon(
              {
                start: startTime,
                end: endTime,
                interval: this.form.timeInterval,
                spacing: this.form.spaceInterval,
                addHeight: this.form.dropHeight,
              },
              () => {}
            );
        } else {
          console.log("error submit!!");
          return false;
        }
      });
    },
  },
};
</script>

<style scoped>
.sunshineAnalysis {
  margin-top: 20px;
}
.el-input {
  width: 180px !important;
}
.demonstration {
  color: white;
}
.el-button {
  width: 123px;
}
</style>